@@ -1,7 +1,6 @@
-
 import re
 
-from typing import Any, cast, Dict, Optional, List
+from typing import Any, cast, Optional
 
 import jsonpointer
 
@@ -19,8 +18,8 @@ class GenericHTTPPort(polled.PolledPort):
         id: str,
         type: str = core_ports.TYPE_BOOLEAN,
         writable: bool = False,
-        read: Dict[str, Any],
-        write: Optional[Dict[str, Any]] = None,
+        read: dict[str, Any],
+        write: Optional[dict[str, Any]] = None,
         **kwargs
     ) -> None:
 
@@ -28,7 +27,7 @@ class GenericHTTPPort(polled.PolledPort):
         self._type = type
         self._writable = writable
 
-        self._write_details: Dict[str, Any] = write or {}
+        self._write_details: dict[str, Any] = write or {}
 
         json_path = read.get('json_path')
         body_regex = read.get('body_regex')
@@ -36,7 +35,7 @@ class GenericHTTPPort(polled.PolledPort):
 
         self._json_path: Optional[str] = json_path
         self._body_regex: Optional[re.Pattern] = re.compile(body_regex) if body_regex else None
-        self._true_values: List[Any] = true_value if isinstance(true_value, list) else [true_value]
+        self._true_values: list[Any] = true_value if isinstance(true_value, list) else [true_value]
 
         super().__init__(id=id, **kwargs)
 
@@ -54,10 +53,14 @@ class GenericHTTPPort(polled.PolledPort):
 
         # JSON pointer lookup
         if self._json_path:
-            if client.last_response_json is None:  # Not a JSON response
+            if client.last_response_json is None:  # not a JSON response
                 return
 
-            raw_value = jsonpointer.resolve_pointer(client.last_response_json, self._json_path)
+            try:
+                raw_value = jsonpointer.resolve_pointer(client.last_response_json, self._json_path)
+            except jsonpointer.JsonPointerException:
+                # Return value unavailable when JSON pointer cannot be resolved instead of propagating the exception
+                return
 
         # Regex pattern match
         elif self._body_regex:
@@ -67,7 +70,6 @@ class GenericHTTPPort(polled.PolledPort):
 
             try:
                 raw_value = match.group(1)
-
             except IndexError:
                 raw_value = match.group()
 
@@ -77,24 +79,23 @@ class GenericHTTPPort(polled.PolledPort):
 
         if self._type == core_ports.TYPE_BOOLEAN:
             return raw_value in self._true_values
-
         else:
             if isinstance(raw_value, bool):
                 return int(raw_value)
-
             elif isinstance(raw_value, str):
                 raw_value = raw_value.strip()
+                factor = 1
+                if raw_value.endswith('%'):
+                    raw_value = raw_value.strip('%')
+                    factor = 0.01
 
                 try:
-                    return int(raw_value)
-
+                    return int(raw_value) * factor
                 except ValueError:
                     try:
-                        return float(raw_value)
-
+                        return float(raw_value) * factor
                     except ValueError:
                         pass
-
             elif isinstance(raw_value, (int, float)):
                 return raw_value
 
